#***************************************************************************
#*   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
#*                                                                         *
#*   This program is free software; you can redistribute it and/or modify  *
#*   it under the terms of the GNU General Public License as published by  *
#*   the Free Software Foundation; either version 2 of the License, or     *
#*   (at your option) any later version.                                   *
#*                                                                         *
#*   This program is distributed in the hope that it will be useful,       *
#*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
#*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
#*   GNU General Public License for more details.                          *
#*                                                                         *
#*   You should have received a copy of the GNU General Public License     *
#*   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
#***************************************************************************
# works on all platforms
import os

# get the directory containing your running .sikuli
myPath = os.path.dirname(getBundlePath())
if not myPath in sys.path: sys.path.append(myPath)
import shared
try:
    setAutoWaitTimeout(10)
    
    shared.initSimple()
    
    click("Units-1.png")
    sleep(1)
    type(Key.ENTER, KEY_CTRL)
    click("Manual.png")
    paste(Pattern("1305987974969.png").similar(0.82), "unit1")
    paste("5ymbl.png", "u1")
    sleep(1)
    type(Key.ENTER, KEY_CTRL)
    sleep(1)
    type(Key.ENTER, KEY_SHIFT)
    doubleClick(find("1383487091620.png").below().find("unit1u1.png"))
    shared.closeCurrentPage()
    click("AfghanAfghan.png")
    click("Download.png")
    
    wait(2)
    
    click("1383499105796.png")
    
    shared.close()
    pass
except FindFailed:
    shared.generateErrorCapture("unit")
    raise



#***************************************************************************
#*   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
#*                                                                         *
#*   This program is free software; you can redistribute it and/or modify  *
#*   it under the terms of the GNU General Public License as published by  *
#*   the Free Software Foundation; either version 2 of the License, or     *
#*   (at your option) any later version.                                   *
#*                                                                         *
#*   This program is distributed in the hope that it will be useful,       *
#*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
#*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
#*   GNU General Public License for more details.                          *
#*                                                                         *
#*   You should have received a copy of the GNU General Public License     *
#*   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
#***************************************************************************
import os
import shutil
from sikuli.Sikuli import *

def openFile(fileName):
	print("Opening "+fileName)
	type("o", KEY_CTRL)
	if exists("1446152114435.png"):
		click("1446152575740.png")
	paste(Pattern("1446149387754.png").similar(0.59), fileName)
	click("1446152645440.png")
	
def openAllPages():	
	type("1", KEY_CTRL)
	type("2", KEY_CTRL)
	type("3", KEY_CTRL)
	type("4", KEY_CTRL)
	type("5", KEY_CTRL)
	type("6", KEY_CTRL)
	type("7", KEY_CTRL)
	type("8", KEY_CTRL)
	type("9", KEY_CTRL)
	type("0", KEY_CTRL+KEY_ALT)	
	type("1", KEY_CTRL+KEY_ALT)	
	type("2", KEY_CTRL+KEY_ALT)	
	type("3", KEY_CTRL+KEY_ALT)	
	
def closeCurrentPage():
	type("w", KEY_CTRL)

def initSimple():
	print("Initialisation with "+Env.getSikuliVersion())
	App.open("skrooge  > /dev/null 2>&1")
	sleep(5)
	#click("1446152344094.png")	

def initAllPlugins():
	initSimple()
	openFile(os.getenv('IN')+"all_plugins.skg")
	sleep(5)
	click("1446152986402.png")

def close():
	App.close("skrooge")

def undo():
    type("z", KEY_CTRL)

def redo():
    type("z", KEY_CTRL+KEY_SHIFT)

def openSettings():
	click("Setting.png")
	click("gunfigureSrg.png")
	click("Vox.png")
	
def createAccount(bankName, accountName):
	type("2", KEY_CTRL)
	paste("1383133694348.png", bankName)
	paste("1383133566859.png", accountName)
	sleep(1)
	type(Key.ENTER, KEY_CTRL)

	closeCurrentPage()

def openReport():
	type("r", KEY_META)

def generateErrorCapture(name):
    img=capture(SCREEN)
    errorCapture=os.path.join(os.getenv('OUT'), name+"/error.png")
    shutil.move(img, errorCapture)
    print "Capture at failure:"+errorCapture
